#
# spec file for package openstack-zaqar
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component zaqar
%define groupname %{component}
%define username %{component}

%define version_unconverted 7.0.1.dev6

Name:           openstack-%{component}
Version:        7.0.1~dev6
Release:        289.1
Summary:        OpenStack Message Bus (Zaqar)
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/stackforge/zaqar
Source:         http://tarballs.openstack.org/zaqar/zaqar-stable-rocky.tar.gz
Source1:        %{name}.conf
Source2:        %{name}.logrotate
# systemd service files
Source10:       %{name}-server.service
Source11:       %{name}-gc.service
Source50:       README.config
BuildRequires:  openstack-suse-macros
BuildRequires:  python-devel
BuildRequires:  python-oslo.config
BuildRequires:  python-pbr
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       logrotate
Requires:       python-zaqar = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  pwdutils
BuildArch:      noarch

%description
Zaqar is an OpenStack project that provides Identity, Token, Catalog
and Policy services for use specifically by projects in the OpenStack
family.

%package -n python-zaqar
Summary:        OpenStack Message Bus (Zaqar) - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.7
Requires:       python-Babel >= 2.3.4
Requires:       python-WebOb >= 1.7.1
Requires:       python-enum34 >= 1.0.4
Requires:       python-falcon >= 1.0.0
Requires:       python-futurist >= 1.2.0
Requires:       python-iso8601 >= 0.1.11
Requires:       python-jsonschema >= 2.6.0
Requires:       python-keystonemiddleware >= 4.17.0
Requires:       python-msgpack >= 0.5.1
Requires:       python2-oslo.cache
Requires:       python-oslo.config >= 5.2.0
Requires:       python-oslo.context >= 2.19.2
Requires:       python-oslo.db >= 4.27.0
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.log >= 3.36.0
Requires:       python-oslo.messaging >= 5.29.0
Requires:       python-oslo.policy >= 1.30.0
Requires:       python-oslo.reports >= 1.18.0
Requires:       python-oslo.serialization >= 2.18.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-pymongo >= 3.0.2
Requires:       python-python-memcached >= 1.56
Requires:       python-requests >= 2.14.2
Requires:       python-six >= 1.10.0
Requires:       python-stevedore >= 1.20.0

%description -n python-zaqar
Zaqar is an OpenStack project that provides Identity, Token, Catalog
and Policy services for use specifically by projects in the OpenStack
family.

This package contains the core Python module of OpenStack Zaqar.

%package gc
Summary:        OpenStack Message Bus (Zaqar) - GC
Group:          System/Management
Requires:       %{name} = %{version}

%description gc
This package contains the OpenStack Zaqar GC Service.

%package server
Summary:        OpenStack Message Bus (Zaqar) - Server
Group:          System/Management
Requires:       %{name} = %{version}

%description server
This package contains the OpenStack Zaqar Server Service.

%package test
Summary:        OpenStack Message Bus (Zaqar) - Testsuite
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-ddt >= 1.0.1
Requires:       python-fixtures >= 3.0.0
Requires:       python-mock >= 2.0.0
Requires:       python-oslotest >= 3.2.0
Requires:       python-testrepository >= 0.0.18
Requires:       python-testtools >= 2.2.0

%description test
The OpenStack Zaqar testsuite. It is used to verify the
functionality of OpenStack Zaqar.

%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep

%build
python setup.py build
#python setup.py build_sphinx -b man
oslo-config-generator --config-file etc/oslo-config-generator/zaqar.conf

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

### directories
install -d -m 750 %{buildroot}%{_localstatedir}/{lib,log}/zaqar
install -D -m 644 %{SOURCE1} %{buildroot}/%_tmpfilesdir/%name.conf

### configuration files
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}/%{component}.conf.d/
install -m 644 etc/zaqar.conf.sample %{buildroot}%{_sysconfdir}/zaqar/zaqar.conf
install -m 644 etc/logging.conf.sample %{buildroot}%{_sysconfdir}/zaqar/logging.conf
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

### README.config
cp %{SOURCE50} %{buildroot}%{_sysconfdir}/%{component}/

# Install systemd unit services
mkdir -p %{buildroot}%{_sbindir} %{buildroot}%{_unitdir}
install -p -D -m 444 %{SOURCE10} %{buildroot}%{_unitdir}/%{name}-server.service
install -p -D -m 444 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}-gc.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-server
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-gc

### test subpackage
%openstack_test_package_install

%pre
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%pre gc
%service_add_pre %{name}-gc.service

%post gc
%service_add_post %{name}-gc.service

%preun gc
%service_del_preun %{name}-gc.service

%postun gc
%restart_on_update %{name}-gc.service
%service_del_postun %{name}-gc.service

%pre server
%service_add_pre %{name}-server.service

%post server
%service_add_post %{name}-server.service

%preun server
%service_del_preun %{name}-server.service

%postun server
%restart_on_update %{name}-server.service
%service_del_postun %{name}-server.service

%files
%defattr(-,root,root)
%doc README.rst ChangeLog
%license LICENSE
%dir %_tmpfilesdir
%_tmpfilesdir/%name.conf
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/lib/%{component}
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/log/%{component}
%dir %attr(0750, root, %{groupname}) %{_sysconfdir}/%{component}
%dir %attr(0750, root, %{groupname}) %{_sysconfdir}/%{component}/%{component}.conf.d/
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/%{component}/%{component}.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/%{component}/logging.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sysconfdir}/%{component}/README.config
#%{_mandir}/man1/zaqar*
%{_bindir}/zaqar-sql-db-manage

%files -n python-zaqar
%defattr(-,root,root,-)
%{python_sitelib}/%{component}
%{python_sitelib}/%{component}-*.egg-info

%files gc
%defattr(-,root,root,-)
%{_bindir}/zaqar-gc
%{_unitdir}/%{name}-gc.service
%{_sbindir}/rc%{name}-gc

%files server
%defattr(-,root,root,-)
%{_unitdir}/%{name}-server.service
%{_sbindir}/rc%{name}-server
%{_bindir}/zaqar-server

%files test
%defattr(-,root,root)
%{_bindir}/zaqar-bench
%{_localstatedir}/lib/openstack-%{component}-test

%changelog
* Sat Oct 27 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.1.dev6:
  * Import legacy-rally-dsvm-zaqar-zaqar
* Tue Sep 18 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.1.dev5:
  * import zuul job settings from project-config
* Sun Sep  9 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.1.dev3:
  * Update .gitreview for stable/rocky
* Sat Sep  8 2018 dmueller@suse.com
- update requirements
* Sat Sep  8 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.1.dev1:
  * Imported Translations from Zanata
  7.0.0
* Fri Aug 31 2018 kwu@suse.com
- switch to stable/rocky branch
* Sat Aug 25 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0rc2.dev2:
  * Using smtplib for Zaqar mail delivery
* Mon Aug 20 2018 nicolas.bock@suse.com
- Fix linter warnings about licenses
* Wed Aug  8 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0rc2.dev1:
  * [trivial] fix some typo
  7.0.0.0rc1
* Sat Jul 28 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b4.dev4:
  * Update os\_client\_config to openstack.config
* Thu Jul 26 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b4.dev3:
  * fix tox python3 overrides
  * Fix wsgiref py3 error
* Wed Jul 25 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b4.dev1:
  * Handle bytes and str in py3
  7.0.0.0b3
* Wed Jul 18 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev36:
  * Remove setting of DEVSTACK\_GATE\_EXERCISES
* Sat Jul 14 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev35:
  * Remove format constraint of client id
* Thu Jul 12 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev33:
  * Remove pool group from zaqar for api-ref
* Sat Jul  7 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev31:
  * Fix assert error during queue creating in ut
  * Remove some unused lib
  * ignore linter error for 'long' type
* Sat Jun 30 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev25:
  * Update the Bugs link for triage
* Sun Jun 24 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev23:
  * Update the method's parameters
* Sat Jun 23 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev21:
  * CONF file structure refactor
* Fri Jun 15 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev19:
  * replace windows line endings with unix format
* Tue Jun 12 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev17:
  * Remove ignore D000 in validation code
* Wed May 30 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev16:
  * Fix format
  * Make doc more clearness
* Sat May 26 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev13:
  * Update pypi url to new url
  * Add release notes link to README
* Wed May 23 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev10:
  * Follow the new PTI for document build
  * Update the lower-constrainsts
* Tue May 22 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev7:
  * Update links in README
* Sat May 19 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev6:
  * Adding Swift backend Region support
* Wed May 16 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev5:
  * Update auth\_url in install docs
* Wed May  9 2018 cloud-devel@suse.de
- Update to version zaqar-7.0.0.0b2.dev3:
  * Update docs to properly describe delete with pop
  7.0.0.0b1
  * Move openstackdocstheme to extensions in api-ref
* Sat Apr 21 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev30:
  * Update auth\_uri option to www\_authenticate\_uri
  * Use rest\_status\_code for api-ref response codes
* Thu Apr 19 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev26:
  * Support query filter in queue
* Fri Apr 13 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev25:
  * Fix one issue in UT
* Fri Mar 30 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev24:
  * Updated from global requirements
* Thu Mar 29 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev23:
  * Remove the deprecated "giturl" option
* Tue Mar 27 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev22:
  * add lower-constraints job
* Mon Mar 26 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev20:
  * Pypy is not checked at gate
  * Updated from global requirements
* Sat Mar 24 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev16:
  * Fix claims on non-existing queue on swift
* Tue Mar 20 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev14:
  * Updated from global requirements
* Sat Mar 17 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev12:
  * Add reserved metadatas for dead letter queue
* Thu Mar 15 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev11:
  * Updated from global requirements
* Tue Mar 13 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev10:
  * Wrap subscriber IP in square brackets when IPv6
  * Fix assert error during queue creating in ut
* Sat Mar  3 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.1.dev7:
  * Imported Translations from Zanata
  6.0.0
* Tue Feb 27 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0rc2.dev6:
  * Modify grammatical errors
* Sat Feb 24 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0rc2.dev4:
  * Imported Translations from Zanata
  * Update reno for stable/queens
* Fri Feb 23 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0rc2.dev1:
  * Nit update in jenkins.rst document
  6.0.0.0rc1
  * The doc of bp support-md5-of-body
* Thu Feb  8 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev9:
  * Support md5 of message body
* Thu Feb  8 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev8:
  * Add heat job to zaqar check pipeline
* Wed Feb  7 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev7:
  * Add some missing releasenotes for Queens
* Thu Feb  1 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev6:
  * Revert "Support md5 of message body"
* Wed Jan 31 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev5:
  * Support md5 of message body
* Sun Jan 28 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev4:
  * Support redis as mgmt storage backend
* Sat Jan 27 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b4.dev3:
  6.0.0.0b3
  * Replace curly quotes with straight quotes
  * Updated from global requirements
  * Remove use of unsupported TEMPEST\_SERVICES variable
* Fri Jan 26 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev28:
  * Remove pool group from zaqar
  * Update .zuul.yaml
* Wed Jan 24 2018 dmueller@suse.com
- make user directory not world readable
* Tue Jan 23 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev24:
  * Imported Translations from Zanata
  * Redis connection support password configure in zaqar
* Sat Jan 20 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev20:
  * msgpack-python has been renamed to msgpack
* Wed Jan 17 2018 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev18:
  * Update the install guide about policy json file
  * Modify delay queue api-doc description
  * Updated from global requirements
* Sat Dec 30 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev13:
  * Updated from global requirements
* Fri Dec 22 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev12:
  * Test delay queues
  * Convert zaqar-tox-integration to native Zuul v3
  * Support delayed queues for mongo
  * Replace pymongo deprecated api
  * Skip period test for message
  * Doc of delayed queues
* Fri Dec 15 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev2:
  * Support delayed queues for swift
* Thu Dec 14 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b3.dev1:
  6.0.0.0b2
  * Support delayed queues for redis
* Fri Dec  8 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev59:
  * Updated from global requirements
  * update devstack README.rst with more info
* Mon Dec  4 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev56:
  * tox -e docs: Line too long
  * Update the documentation link
  * Zuul: add file extension to playbook path
  * Updated from global requirements
  * Missing claim\_count in mongodb MessageController \_basic\_message
  * Remove setting of version/release from releasenotes
* Sun Dec  3 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev45:
  * Fix gate job failure
* Tue Nov 21 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev44:
  * zuul: run TripleO jobs with new zuulv3 layout
  * Updated from global requirements
* Fri Nov 17 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev41:
  * Policy in code: Update the related doc
* Tue Nov 14 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev40:
  * Updated from global requirements
  * Add input type check
* Mon Nov 13 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev37:
  * Clean up useless code
  * Migrate to Zuul v3
* Sun Nov 12 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev33:
  * Cleanup test-requirements
* Sat Nov 11 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev31:
  * Remove bundled intree tempest plugin from Zaqar
* Fri Nov 10 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev29:
  * Updated from global requirements
  * Do not use “-y” for package install
  * Use dict.keys() for key iteratation
* Tue Nov  7 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev23:
  * Use generic user for both zuul v2 and v3
  * Remove the remaining flavor tuple in test\_put\_auto\_get\_capabilities test
  * Register default subscription policies in code
  * Reduce swiftclient logging
* Sat Nov  4 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev16:
  * Register default pools and health policies in code
* Fri Nov  3 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev14:
  * Create subscription return error id
  * Metadata zero value will skip valid check
  * Register default claim and flavors policies in code
* Sun Oct 29 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev8:
  * Add dbid parameter to pools's uri based on redis
* Sat Oct 28 2017 cloud-devel@suse.de
- Update to version zaqar-6.0.0.0b2.dev6:
  * Add more backoff functions
  6.0.0.0b1
* Wed Oct 25 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev51:
  * Register default message policies in code
  * Imported Translations from Zanata
* Sat Oct 21 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev48:
  * Move to Zuulv3 link to check status
  * Register default queue policies in code
* Fri Oct 20 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev45:
  * flavor.update's parameter capabilities error in flavor.create
* Thu Oct 19 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev44:
  * Correct descriptions of install doc
* Wed Oct 18 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev42:
  * delete some no use code
  * Implement basic policy module in code
* Tue Oct 17 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev38:
  * Update message api-ref
* Mon Oct 16 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev37:
  * Remove deprecated context usage
* Fri Oct 13 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev35:
  * Escape IPv6 address in square brackets
  * Updated from global requirements
  * Reduce duplication in swift post messages
* Wed Oct 11 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev30:
  * fix a typo for retry policy
* Tue Oct 10 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev29:
  * Updated from global requirements
  * Correcting typo on doc
  * Adding folder path
  * Delete some duplicate code of mongodb/claims.py
  * Correct some typos
  * Port Rally Task to format v2
* Fri Sep 29 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev19:
  * Retry container creation in swift
* Wed Sep 27 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev18:
  * Remove iso8601\_from\_timestamp
  * Remove "enabled" in CORS guide
* Tue Sep 26 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev14:
  * Updated from global requirements
* Wed Sep 20 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev13:
  * Fix gate-grenade jenkins failure
* Wed Sep  6 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev12:
  * Replace http with https for doc links
* Tue Sep  5 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev11:
  * Fix mongodb scoped\_query's param note
* Sat Sep  2 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev9:
  * [api-ref]Change 'queues' to required in response body
* Fri Sep  1 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.1.dev7:
  * Fix Py27/35 jenkins failure
  5.0.0
* Sat Aug 26 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0rc2.dev6:
  * Remove usage of parameter enforce\_type
* Thu Aug 24 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0rc2.dev5:
  * Correct typo of zaqar index doc page
* Tue Aug 15 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0rc2.dev4:
  * Imported Translations from Zanata
  * Update reno for stable/pike
  5.0.0.0rc1
* Sat Aug 12 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev36:
  * Fix unconfirm for swift backend
  * Fix claims of MongoDB when enabling DLQ
* Fri Aug 11 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev32:
  * Fix claims for redis when enabling DLQ
  * Use doc8 check
  * Add some more uwsgi options for zaqar-uwsgi
  * Update the dead letter queue's releasenote
  * Update and optimize documentation links
* Thu Aug 10 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev23:
  * Notification Delivery Policy
* Tue Aug  8 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev22:
  * Fix bug in mongodb backend for dead letter queue
* Mon Aug  7 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev20:
  * Fix tempest test\_set\_and\_get\_queue\_metadata
* Fri Aug  4 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev18:
  * Support dead letter queue for swift
* Wed Aug  2 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev16:
  * Fix api doc in creating pre-signed url
  * Remove install-guide env which is no longer effective
* Tue Aug  1 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev12:
  * Add project info to contributor doc
  * Remove Deprecation tempest Warning
  * Updated from global requirements
  * Replace mongodb backend pymongo deprecated API
  * Support dead letter queue for redis
* Sat Jul 29 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b4.dev4:
  * Migrate configuration docs
  * Stop using deprecated 'message' attribute in Exception
  5.0.0.0b3
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev56:
  * Fix a small bug in dead queue patch
* Tue Jul 25 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev55:
  * Replace uuid.uuid4().hex with uuidutils.generate\_uuid()
* Fri Jul 21 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev54:
  * Fix message claim expires problem in swift storage
  * Updated from global requirements
  * Trivial Fix in api-ref
  * Support dead letter queue for MongoDB
* Thu Jul 20 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev47:
  * Refactor the doc tree
* Wed Jul 19 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev46:
  * Update URL home-page in documents according to document migration
  * Minor cleanup on conf.py files
* Tue Jul 18 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev43:
  * Updated from global requirements
* Mon Jul 17 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev42:
  * Fix mongodb list method's param note
* Thu Jul 13 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev41:
  * Use mongodb delete\_one method instead of deprecated remove method
* Mon Jul 10 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev39:
  * Support to query single resource with pre-signed url
* Thu Jul  6 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev38:
  * Add log hacking rules
* Wed Jul  5 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev36:
  * Fix html\_last\_updated\_fmt for Python3
  * Revert "Remove startup check from devstack"
  * Remove obsolete user-guide
  * Switch from oslosphinx to openstackdocstheme
  * Update subscription confirm doc
  * Support dot character in queue's name
  * Optimize the link address
  * Fix some reST field lists in docstrings
* Fri Jun 30 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev23:
  * Add release note: allow configuration of websocket notification
  * Remove unused None from dict.get()
* Thu Jun 29 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev20:
  * Allow configuration of websocket notification
* Tue Jun 27 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev18:
  * Remove unnecessary parameter in Zaqar
  * Using assertFalse(A) instead of assertEqual(False, A)
* Fri Jun 23 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev14:
  * Updated from global requirements
  * Fix jenkins link in running-tests
* Wed Jun 21 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev12:
  * Fix some typos in zaqar
* Sat Jun 17 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev10:
  * Use oslo\_db for create\_engine
* Thu Jun 15 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev8:
  * Remove log translations
* Wed Jun 14 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev6:
  * Updated from global requirements
  * Fix the official Doc site of CORS
  * API Ref bug about the mailto protocol
* Tue Jun 13 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b3.dev2:
  * modify doc of Claim messages
  5.0.0.0b2
  * Simplify SQL run() method
* Sat Jun 10 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev41:
  * Fix OSProfiler issue for Swift and Redis driver
* Wed Jun  7 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev39:
  * Ignore dead subscriptions in Swift backend
* Tue Jun  6 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev38:
  * Remove unused methods from the swift backend
* Mon Jun  5 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev37:
  * Replace deprecated oslo.messaging.get\_transport with get\_notification\_transport
* Sat Jun  3 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev35:
  * Remove usage of parameter enforce\_type
* Fri Jun  2 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev34:
  * Updated from global requirements
* Thu Jun  1 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev33:
  * Updated from global requirements
* Fri May 26 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev32:
  * Updated from global requirements
* Fri May 19 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev31:
  * [Swift] Fix 503 error when get queue stats
  * Replace test.attr with decorators.attr
* Fri May  5 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev27:
  * Correct the trace name for redis
  * Fix list detailed queue without reserved metadata
* Wed May  3 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev24:
  * Use absolute path for executables
* Sat Apr 29 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev23:
  * Fix queues actions for pooling
* Wed Apr 26 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev21:
  * Revise text about py34
  * Fix swift messages posting when pooling
  * Switch to use stable data\_utils
  * Switch to use test\_utils.call\_until\_true
  * Use auth\_type instead of auth\_plugin
  * Switch to decorators.idempotent\_id
  * Fix wrong value of require\_confirmation
  * Replace assertTrue(\*>\*) with assertGreater
  * Use \_LW() to wrap the warning message
  * Use pop in message\_delete\_many
  * Use KEYSTONE\_IDENTITY\_BACKEND
  * Using oslo\_config's min attribute
  * Start accepting \*\*kwargs in service clients
  * Support \`messages\` API ref
  * Add \`Pre-signed queue' api ref
  * Add \`Health\` api ref
  * Use is\_valid\_ipv6 from oslo.utils
  * Make the notifier max\_workers configurable
  * Fix service\_available opt registration and extra comma
  * Add \`\_max\_messages\_post\_size\` and \`\_default\_message\_ttl\` for queue
  * Fix arguments order in error\_response (Websocket)
  * Fix subscriptions\_post resource in wsgi 2 homedoc
  * Fix typo in test\_on\_mesage\_with\_invalid\_input
  * Make enforce\_type=True in CONF.set\_override
  * Fix requirements of message\_delete\_many API
  * Make zaqar-bench use credentials from os\_client\_config
  * Make enforce\_type=True in CONF.set\_override
  * Move subscription test from v1\_1 to v2
  * Replace assertEqual(None, \*) with assertIsNone in tests
  * Fix duplicate auth\_section issue
* Fri Apr 21 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev17:
  * Fix failure when adding swift/redis as pool
  * Remove enabled option for CORS
* Wed Apr 19 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev15:
  * Updated from global requirements
* Fri Apr 14 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev14:
  * swift driver: rely on keystone session for swift connection
* Thu Apr 13 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev12:
  * Add missing modules to config generator
  * Add .idea pattern to .gitignore
* Wed Apr 12 2017 cloud-devel@suse.de
- Update to version zaqar-5.0.0.0b2.dev9:
  * Add domain configuration in Swift backend
  5.0.0.0b1
* Tue Apr 11 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev75:
  * Updated from global requirements
  * Fix detailed missing in api-ref
  * Check if swift is alive instead of hardcode
* Mon Apr 10 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev69:
  * Remove redundancy code
* Sat Apr  8 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev67:
  * Automatically get pools capabilities for flavor
* Tue Apr  4 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev66:
  * Using generic instead of v3 for identity
* Wed Mar 29 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev65:
  * Support CORS
* Fri Mar 24 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev64:
  * Fix the link of 'Message Queuing API v2'
  * Use HostAddressOpt for opts that accept IP and hostnames
  * Move auth and osprofiler to middleware folder
* Tue Mar 21 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev60:
  * Updated from global requirements
  * Don't share swift client instances
* Sat Mar 18 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev57:
  * Add missing content type in Swift objects
* Tue Mar 14 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev55:
  * Fix claim ttl test
* Mon Mar 13 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev53:
  * Updated from global requirements
  * Introduce Guru to Zaqar
* Thu Mar  9 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev50:
  * Switch to use stable data_utils
  * Make import clearly in i18n.py
* Tue Mar  7 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev47:
  * Support cold migration
* Mon Mar  6 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev45:
  * Use Sphinx 1.5 warning-is-error
  * Fix api-ref building
  * Remove unused import
  * Using cp insteald ln for zaqar-ui
* Fri Mar  3 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev37:
  * [Fix gate]Update test requirement
* Mon Feb 27 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev36:
  * Remove table creation from the SQL driver
* Thu Feb 23 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev34:
  * Set wsgi name to application
* Thu Feb 23 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev32:
  * Filter empty messages when creating claims in Swift
  * Ignore conflict when deleting queues with Swift
* Tue Feb 21 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev28:
  * Check body type when patching subscription
* Sat Feb 18 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev26:
  * Updated from global requirements
* Thu Feb 16 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev25:
  * Subscription Confirmation Support-3
  * Address TODO in schema
* Wed Feb 15 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev21:
  * Add the missed decorator to pools
* Tue Feb 14 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev19:
  * Switch to use test_utils.call_until_true
  * Remove the Warning log
  * Use auth_type instead of auth_plugin
  * Add Swift backend releasenote
  * Update the purge exception catch
* Fri Feb 10 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev11:
  * Replace github with git.openstack.org
  * Sync the resource string
  * Remove "TODO" as already support gettext
  * Update reno for stable/ocata
* Thu Feb  9 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0rc2.dev3:
  * Using os-testr to get better report
  * Fix typo
  4.0.0.0rc1
* Sat Feb  4 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b4.dev7:
  * Fix sqlalchemy migration
* Fri Feb  3 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b4.dev5:
  * Enable swift in the gate hook
* Thu Feb  2 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b4.dev3:
  * Add the release note for OSprofiler feature
* Tue Jan 31 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b4.dev2:
  * Updated from global requirements
* Mon Jan 30 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b4.dev1:
  4.0.0.0b3
  * Switch to decorators.idempotent_id
* Sat Jan 28 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev33:
  * Remove py34 support in favour of py35
* Thu Jan 26 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev31:
  * Add validation of limit value in querying flavors and poolss
  * Swift storage
* Wed Jan 25 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev27:
  * Replace assertTrue(*>*) with assertGreater
* Tue Jan 17 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev25:
  * Make the log work when deploy Zaqar with uwsgi
  * Fix wrong value of require_confirmation
  * Fix typos in HACKING.rst
* Wed Jan 11 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev20:
  * Use _LW() to wrap the warning message
  * Fix unit test unstable issue
  * Add tempest test for purge queue
  * Clean transport logs for API endpoints
* Tue Jan 10 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev14:
  * Removes unnecessary utf-8 encoding
* Mon Jan  9 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev12:
  * Use pop in message_delete_many
* Fri Jan  6 2017 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev10:
  * don't allow get/update/delete subscirtions with wrong queue
  * Updated from global requirements
* Sat Dec 31 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev7:
  * Enable coverage report in console output
* Wed Dec 28 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev6:
  * Update README.rst
  * Fix CI failure
* Fri Dec 23 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev4:
  * Add API ref of purging queue
* Wed Dec 21 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev3:
  * Support purge queue -- websocket
* Tue Dec 20 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b3.dev1:
  * insert Apache 2.0 license into source file
  4.0.0.0b2
* Fri Dec 16 2016 tbechtold@suse.com
- Update to version zaqar-4.0.0.0b2.dev22:
  * Add support for sqlalchemy migration based on alembic
  * Support purge queue -- wsgi
  * Add OSprofiler guide
* Thu Dec 15 2016 aplanas@suse.com
- Configuration cleanup
- Document new configuration handling
* Wed Dec 14 2016 aplanas@suse.com
- Create /etc/zaqar/zaqar.conf.d
* Tue Dec 13 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev16:
  * Convert user getting started guide to rst
* Fri Dec  9 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev14:
  * Remove startup check from devstack
  * Fix SSL and verbose issue of zaqar bench
* Thu Dec  8 2016 aplanas@suse.com
- systemd: remove Wants from services.
* Thu Dec  8 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev10:
  * Consistent  with the project code
  * Add missing policy check for queue stats and share
* Tue Dec  6 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev7:
  * Updated from global requirements
* Sat Dec  3 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev6:
  * Show team and repo badges on README
* Fri Dec  2 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev4:
  * Updated from global requirements
  * Add Feature section in doc
* Mon Nov 28 2016 tbechtold@suse.com
- Switch to systemd service files
- Fix tmpfiles creation
* Thu Nov 24 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev2:
  * Use KEYSTONE_IDENTITY_BACKEND
* Wed Nov 23 2016 cloud-devel@suse.de
- Update to version zaqar-4.0.0.0b2.dev1:
  * Integrate OSprofiler with Zaqar
  4.0.0.0b1
* Sun Nov 20 2016 dmueller@suse.com
- package license file
* Thu Nov 17 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev29:
  * Fix an typo in flavors.inc
  * Add some descriptions for resources in API Ref
* Wed Nov 16 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev26:
  * Fix zaqar client gate
  * Use build interval and timeout from conf
* Fri Nov 11 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev23:
  * Fix zaqar-ui clone issue
* Wed Nov  9 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev22:
  * Reword description of grace
  * Don't send confirmation notification if it's not enabled
* Mon Nov  7 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev18:
  * Updated from global requirements
* Sat Nov  5 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev17:
  * Enanble Zaqar-UI in devstack
* Fri Nov  4 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev15:
  * Update .coveragerc after the removal of openstack directory
* Mon Oct 10 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev14:
  * Enable release notes translation
  * Subscription Confirmation Support-2
* Sun Oct  9 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev10:
  * Fix doc build if git is absent
* Wed Oct  5 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev9:
  * Updated from global requirements
* Tue Oct  4 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev8:
  * Fix a typo: remove redundant 'the'
* Sun Oct  2 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev7:
  * Using oslo_config's min attribute
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev6:
  * Change assertTrue(isinstance()) by optimal assert
* Mon Sep 26 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev5:
  * [api-ref] Remove temporary block in conf.py
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev4:
  * Don't check key format in mongodb
* Sun Sep 18 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0rc2.dev2:
  * Update reno for stable/newton
  3.0.0.0rc1
* Fri Sep 16 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev15:
  * Add install guide for ubuntu and suse
* Thu Sep 15 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev14:
  * Remove small duplication from message storage
* Wed Sep 14 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev12:
  * Consolidate constants to a module
* Tue Sep 13 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev10:
  * Officially deprecate API v1.1
* Sat Sep 10 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev8:
  * Fix links in devstack/README.rst
* Wed Sep  7 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev6:
  * Updated from global requirements
  * Config logABug feature for zaqar api-ref
* Tue Sep  6 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev2:
  * Disable DEPRECATED API versions by default
* Fri Sep  2 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b4.dev1:
  * Clean imports in code
  3.0.0.0b3
* Mon Aug 29 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev29:
  * Clean the auth app after authentication failure
  * Let v2 tempest base on the base tests
* Fri Aug 26 2016 aplanas@suse.com
- Revert generate PID file for systemd (bsc#991985)
* Thu Aug 25 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev27:
  * Remove openstack-doc-tools
  * Get ready for os-api-ref sphinx theme change
* Tue Aug 23 2016 aplanas@suse.com
- Generate PID file for systemd (bsc#991985)
* Tue Aug 23 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev24:
  * Use upper constraints for all jobs in tox.ini
* Mon Aug 22 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev23:
  * Fix a minor error in API reference
* Fri Aug 19 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev21:
  * Subscription Confirmation Support-1
  * Remove the useless function
* Sat Aug  6 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev17:
  * Don't check for project-id if accessing the / route
* Thu Aug  4 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev16:
  * Adding Negative tests cases to Zaqar v2
  * Start accepting **kwargs in service clients
* Wed Aug  3 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev14:
  * Cleanup i18n marker functions to match Oslo usage
* Sun Jul 31 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev12:
  * Fix errors in API reference for message resource
  * modify the home-page info with the developer documentation
  * Add flavors api ref
  * Support `messages` API ref
* Wed Jul 27 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev5:
  * Updated from global requirements
* Fri Jul 22 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev4:
  * Remove docs,comments,references to Oslo Incubator
* Thu Jul 21 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev3:
  * Ensure queue exists before get/update the claim
* Mon Jul 18 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b3.dev2:
  * This patch removes extra spaces from files
  3.0.0.0b2
* Fri Jul 15 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev73:
  * Add Python 3.5 classifier and venv
* Thu Jul 14 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev71:
  * Fix falcon.HTTPConflict initialization getting error
  * Add a trust notifier task
  * Cleanup integration tests setup
* Sun Jul 10 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev66:
  * Fixes: Typo in comments
* Sat Jul  9 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev65:
  * Config: no need to set default=None
* Fri Jul  8 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev63:
  * Add pools api ref
* Thu Jul  7 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev62:
  * Disable warnerrors=true in setup.cfg
  * Add `Pre-signed queue' api ref
  * Add `Health` api ref
  * Delete in tree config ref
* Tue Jul  5 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev55:
  * Updated from global requirements
  * Fix issue with subscription list in Redis
  * Remove tempest smoke tests run
  * Fix the wrong check of X-PROJECT-ID
* Wed Jun 29 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev48:
  * (redis)Fix the 503 error when get/delete messages
* Sat Jun 25 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev47:
  * Add subscription api ref
  * Add Claims for api ref
* Wed Jun 22 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev43:
  * Fix debug log missing issue
  * Remove leftovers on websocket disconnections
  * Add Zaqar installation guide
* Tue Jun 21 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev37:
  * Fix config parsing in zaqar-server
* Mon Jun 20 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev36:
  * Updated from global requirements
* Sun Jun 19 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev34:
  * Relocates cli options registration from bootstrap to server
* Sat Jun 18 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev32:
  * Fix incorrect message when getting non-existing claim
* Fri Jun 17 2016 cloud-devel@suse.de
- Update to version zaqar-3.0.0.0b2.dev30:
  * Fix post install jobs
  * Add release note for bug 1590173
  * Add Queues for api ref
  * Make queues lazy in subscriptions
  * Add release notes
  * Use is_valid_ipv6 from oslo.utils
  * Use debug instead of warning for pipeline implement error
  * Fix subscription limit per queue
  * Fix fail of getting claim after claim expire(Redis)
  * Make the notifier max_workers configurable
  * Show 'age' field in subscriptions (redis)
  * Show 'age' field in subscriptions (mongodb)
  * Add reserved metadata check
  * Support Tempest test as gate job
  * Avoid multi-threading problem with sql backend
  * Fix fail of claim after some message expire(Redis)
  3.0.0.0b1
  * Always use pip constraints
  * Define context.roles with base class
  * Rename notification/task to notification/tasks
  * Changed assertTrue(isinstance()) to assertIsInstance
  * Use assertEqual/GreaterEqual/LessEqual
* Wed Jun  1 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev42:
  * Init commit to add API ref in tree
* Tue May 31 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev40:
  * Improve the log to avoid unexpected ERROR
* Mon May 30 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev38:
  * Updated from global requirements
* Sun May 29 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev37:
  * Use run() wrapper instead of connection.execute()
* Sat May 28 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev36:
  * Replace tempest-lib with tempest.lib
* Fri May 27 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev35:
  * Refactor zaqar/storage/utils.py to respect DRY
* Tue May 24 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev34:
  * remove verbose option in devstack plugin
  * Fix falcon confilct in requirements.txt
  * Fix py34 gate job
* Mon May 16 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev30:
  * Trivial: remove openstack/common in flake8 exclude list
* Sat May 14 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev28:
  * Move to falcon middleware
* Wed May 11 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev27:
  * Fix cache decorator tests
* Mon May  9 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev25:
  * Imported Translations from Zanata
  * Updated from global requirements
  * Fix wrong claim error message
* Mon May  9 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev20:
  * Default message ttl is needed to change correctly
  * Fix service_available opt registration and extra comma
* Thu Apr 21 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.1.dev16:
  * Make sure use IPv6 sockets for Zaqar in IPv6 environment
  2.0.0
  * Validate PUT of reserved queue attributes metadata
  * Warn on upcoming deprecations for v1.0 and v1.1
  * Update .gitreview for stable/mitaka
* Sat Apr 16 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev18:
  * Fix auth issue when accessing root path "/"
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev16:
  * expires should be checked when using pre-signed url
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev14:
  * Show default attributes for queue
  * Replace "MARCONI" with  "ZAQAR"
  * Add  oslo_config IPOpt support
  * Update README.rst  in zaqar project
  * Implements base classes  for storage controllers
* Mon Apr 11 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev13:
  * Updated from global requirements
* Fri Apr  8 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev12:
  * Added samples in multiple languages
* Wed Apr  6 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev10:
  * Updated from global requirements
* Tue Apr  5 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev9:
  * Fix tempest tests list
* Fri Apr  1 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev7:
  * Generate oslo.cache options via tox -e genconfig
* Sat Mar 26 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev5:
  * Validate PUT of reserved queue attributes metadata
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev3:
  * Warn on upcoming deprecations for v1.0 and v1.1
* Sat Mar 19 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0rc2.dev1:
  * Update reno for stable/mitaka
  2.0.0.0rc1
  * Fix PATCH queue's metadata
  * Remove unnecessary assert
  * Fix cleanup in metadata putting test
  * Add missing /ping for v1.1 homedoc
* Fri Mar 18 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev8:
  * Don't pass debug option to websocket constructor
* Mon Mar 14 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev7:
  * Updated from global requirements
* Sun Mar 13 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev5:
  * Renew subscription on update with TTL
* Sat Mar 12 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev4:
  * Forbid update subscription to duplicate
* Fri Mar 11 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev3:
  * Fix updating subscription options in Redis driver
* Tue Mar  8 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev2:
  * Remove unused pngmath Sphinx extension
* Mon Mar  7 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b4.dev1:
  * Updated from global requirements
  2.0.0.0b3
* Fri Mar  4 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b3.dev78:
  * Support metadata update issue for v2
  * Fix the TTL issue of subscriptions for MongoDB
  * Fix the TTL issue of subscriptions for Redis
  * Fix freeze on some requests
  * Add `_max_messages_post_size` and `_default_message_ttl` for queue
* Thu Mar  3 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b3.dev69:
  * Updated from global requirements
  * Fix validation in websocket unit tests
  * Add tempest test for wsgi v2
  * Add description to 404 and 409 error responses
  * Support binary messages over websocket
  * Add tempest test for v1.1
  * Fix the tempest test error
  * Catch NoPoolFound on resource listing in transport
  * Fix arguments order in error_response (Websocket)
  * "group" word should be used instead "pool"
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b3.dev51:
  * Fix cross-transport error handler
  * Fix subscriptions_post resource in wsgi 2 homedoc
  * Updated from global requirements
  * Add zaqar tempest plugin
  * Update operation should return updated result
  * Fix 500 error when create pools in wsgi v2
  * Get non-existing queue should return 200
  * Ensure hmget return right data format
  * Don't return links if subscriptions are empty
  * Updated from global requirements
  * Add queue name to notifications
  * Use Client-ID in devstack ping request to Zaqar
  * Fix improperly LOG using in Zaqar
  * Add the missing Client-ID check in wsgi v2
  * Make error response better for patching flavors
  * Use uppercase 'S' in word "OpenStack"
  * Don't return links if subscriptions are empty
  * Update homedoc in wsgi v2
  * Updated from global requirements
  * Fix typo in test_on_mesage_with_invalid_input
  * Replace six.iteritems(dict) with dict.items()
  * Ensure JSON sent over websocket is a dictionary
  * Imported Translations from Zanata
  * Updated from global requirements
  * Make enforce_type=True in CONF.set_override
  * Remove argparse from requirements
  * Use default pool for queue listing
  * Add new information to zaqar-bench tutorial
  * Fix zaqar-bench auth method detection
* Fri Jan  8 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev41:
  * Updated from global requirements
  * Make websocket.html process notifications
  * Refactoring of docs during Mitaka cycle
  * Move subscription test from v1_1 to v2
  * Replace deprecated LOG.warn with LOG.warning
  * Fix the docs link
  * Replace assertEqual(None, *) with assertIsNone in tests
* Thu Jan  7 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev27:
  * Use assertTrue/False instead of assertEqual(T/F)
  * Move in-line function outside method
  * Updated from global requirements
* Wed Jan  6 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev22:
  * Trival: Remove unused logging import In some files
  * Drop MANIFEST.in - it's not needed with PBR
* Tue Jan  5 2016 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev19:
  * Fix for the deprecated library function
  * Changing LOG.warn to LOG.warning
  * remove python 2.6 trove classifier
  * Deprecated tox -downloadcache option removed
  * Put py34 first in the env order of tox
* Sat Dec 12 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev9:
  * Updated from global requirements
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev8:
  * Imported Translations from Zanata
  * Fix zaqar-bench not working
  * Updated from global requirements
  * Fix queue create failure when metadata is {}
* Thu Dec 10 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.0b2.dev2:
  * Explicitly use asyncio protocol for websockets
  2.0.0.0b1
  * Remove version from setup.cfg
* Sat Dec  5 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev71:
  * Fix duplicate auth_section issue
  * Add unreleased notes for releasenotes tree
* Wed Nov 25 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev68:
  * Updated from global requirements
  * Add the default repos into devstack/settings file
  * Move development.environment.rst to standard location
* Sat Nov 21 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev62:
  * Automatically drop functional tests databases
* Thu Nov 19 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev60:
  * Replace "MARCONI" with "ZAQAR"
  * Fix typo
  * Fix write concern check for py34
  * Fix tox not performing some tests in some Envs
* Wed Nov 18 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev54:
  * Replace "MARCONI" with  "ZAQAR"
* Tue Nov 17 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev53:
  * Remove netaddr useless requirement
* Mon Nov 16 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev51:
  * Added CONTRIBUTING.rst file
  * Updated from global requirements
* Wed Nov 11 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev48:
  * Updated from global requirements
  * Correctly stop uwsgi process during unstack.sh
* Tue Nov 10 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev45:
  * Add reno for release notes management
  * Add oslo_config IPOpt support
* Mon Nov  2 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev42:
  * Use oslo_config new type PortOpt for port options
  * Some prerequisites for Fedora OS is missing in zaqar README.rst
* Sat Oct 24 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev38:
  * Imported Translations from Zanata
* Tue Oct 20 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev37:
  * Fix mongodb.conf corruption during stack.sh
  * Use keystonemiddleware in config generation conf
  * Fix client constructor for zaqar-bench
  * WebSocket functional tests
* Sat Oct 17 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev29:
  * Updated from global requirements
  * Some prerequisites for Ubuntu OS is missing in zaqar README.rst
  * Make websocket run in correct logging mode
* Thu Oct 15 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev23:
  * Fix incorrect usage of assertEqual() in some tests
  1.0.0
  * Imported Translations from Zanata
  * Cleanup of Translations
* Wed Oct 14 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev44:
  * FIX TypeError for list queue command
* Sat Oct 10 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev42:
  * Adding namespace for [drivers] section in oslo-config-generator
  * Updated from global requirements
  * Fix order of arguments in assertEqual
* Fri Oct  9 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev37:
  * Notifications over websocket
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
  * Fix order of arguments in assertEqual
* Thu Oct  8 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev17:
  * Removes redundant debug option
* Wed Oct  7 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev15:
  * Updated from global requirements
* Tue Oct  6 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev14:
  * The `subtype` formatting arg does not exist
* Sat Oct  3 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev12:
  * Fix order of arguments in assertEqual
  * Imported Translations from Zanata
* Tue Sep 29 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev9:
  * Fix order of arguments in assertEqual
* Fri Sep 25 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev8:
  * Cleanup of Translations
  * Use decorator instead of request logging in responders
  * Switch to oslo_cache
* Thu Sep 24 2015 cloud-devel@suse.de
- Update to version zaqar-2.0.0.dev3:
  * Open Mitaka development
  1.0.0.0rc1
  * Updated from global requirements
  * Add note for unreliable in README.rst
  * Rename get_group to get_pools_by_group
* Wed Sep 23 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev70:
  * Fix 500 error when adding pool to wrong group
* Tue Sep 22 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev68:
  * Adds max failure rate limit
  * Allow running zaqarclient for gate tests
  * Close backend connections in tests
  * Fix few typos in headings
* Mon Sep 21 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev60:
  * Updated from global requirements
  * Fix redis tests
* Sun Sep 20 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev57:
  * Correct "log_file" option in zaqar documents
  * Fix duplicated queues on multi pools
* Sat Sep 19 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev53:
  * Max failure percent not longer needed for Rally gate
  * Imported Translations from Zanata
* Thu Sep 17 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev50:
  * Fix devstack option to plugin zaqar
  * Fix "message_store" config option in zaqar doc
  * Fix usage of mongo test URL
* Tue Sep 15 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev45:
  * Add Redis backend docs
  * RBAC support based on oslo.policy
  * Use a Text field instead of Binary
  * Hide project id for flavor
* Mon Sep 14 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev37:
  * Add a global error handler for wsgi
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev35:
  * Prevent mutation of out-of-scope args
  * Don't raise 404 on missing queues
  * Ensure group exists on updates
  * Fix error messages formatting
  * Don't create a connection on constructor
  * Enable pooling for redis' job
  * Don't set keystone as auth if not enabled
  * Let devstack redirect output
* Tue Sep  8 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev20:
  * Fix accurate links in README.rst
  * Refactoring to make Websocket driver available in v2
* Mon Sep  7 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev16:
  * Remove race condition in test_claim_lifecycle
* Sat Sep  5 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev15:
  * Fix typos in sqlalchemy flavor.py
  * Don't register the default pool
  * Fix duplicated notification
* Fri Sep  4 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev10:
  * Add email driver for notification
  * Updated from global requirements
  * Support various paths for signed URLs
  * Add unittests for Flavors in sqlalchemy
  * Restore sqlalchemy unit tests
* Thu Sep  3 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b4.dev2:
  * Use thread executor all the time for notifier
  1.0.0.0b3
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev66:
  * s/update/_update/ sqlalchemy's pool controller
  * Add support for flavors in sqlalchemy
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev64:
  * Return empty `links` on empty collections
  * Fixed the mistake in zaqar dev-environment
  * Fix GET queue metadata for sqlalchemy
  * Support signed URLs in WebSocket
  * Set a secret key in devstack
* Tue Sep  1 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev54:
  * Updated from global requirements
  * Update 'doc/source/development-environment.rst'
  * Update README.rst in zaqar project
* Sat Aug 29 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev49:
  * Removing unused dependency: discover
  * Fix typos in test_suite.rst and test_utils.py
  * The link for plugin samples is updated
* Fri Aug 28 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev43:
  * Make False as default value for `unreliable`
  * Don't generate docs for zaqar.transport.wsgi.app
  * Updated from global requirements
* Thu Aug 27 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev40:
  * API v1.1 Claims endpoints
  * Move _(get|inc)_counter out of QueueController
* Wed Aug 26 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev36:
  * Mistakes in the sentences are corrected
  * Fix WS deauthenticate
* Thu Aug 20 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev33:
  * Use the executor directly in notifier
* Sat Aug 15 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev31:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Fix WS endpoint registration
  * Authentication for websocket
  * Fix validation errors handling in websocket
* Thu Aug 13 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev22:
  * Refactor notification framework
  * Add a websocket example
* Fri Aug  7 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev18:
  * Add configuration to run service using uwsgi
  * Set auth_strategy in devstack
* Thu Aug  6 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev14:
  * Remove unused oslo-incubator modules
  * Remove mock side_effect in test_messages
  * Skip tasks run when there is no subscriber
* Wed Aug  5 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev9:
  * Updated from global requirements
  * Imported Translations from Transifex
* Tue Aug  4 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b3.dev6:
  * Imported Translations from Transifex
  * Enable tox debug
  * Move to using the futurist library for async executors
  1.0.0.0b2
  * Fix enabling of Zaqar in Devstack plugin
* Fri Jul 31 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev40:
  * Decouple the queue and subscription
  * Return the websocket response on invalid request
* Wed Jul 29 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev36:
  * Updated from global requirements
  * Imported Translations from Transifex
  * Return subscription ID on create
  * Handle missing document in subscription operations
  * Send message notifications as json
  * Enable message pipeline on devstack
  * Update development documentation
  * Allow config of mongo test url using env variable
  * Add signed URL verification
  * Add pre-signed url generation endpoint
* Wed Jul 22 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev16:
  * Update README
* Thu Jul 16 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev15:
  * Make errors preventing driver load more useful
* Wed Jul 15 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev13:
  * Fix test failure linked to new mock release
* Thu Jul  9 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev12:
  * Imported Translations from Transifex
  * Move common configs under common.configs
  * Validate UUIDs before the driver sends them
  * Update development-environment.rst guide
* Wed Jul  8 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev5:
  * Updated from global requirements
* Tue Jul  7 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev3:
  * API v1.1 Messages endpoints
* Thu Jul  2 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0b2.dev1:
  * Satisfy abstract base by adding queue_controller
  1.0.0.0b1
* Thu Jun 25 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0a1.dev8:
  * Move functional tests out of tests/
* Wed Jun 24 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0a1.dev6:
  * Add support for pymongo 3.0.2
* Sun Jun 21 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0a1.dev4:
  * Imported Translations from Transifex
* Wed Jun 17 2015 cloud-devel@suse.de
- Update to version zaqar-1.0.0.0a1.dev3:
  * Update version for Liberty
  1.0.0a0
  * Added 'pool name' and 'flavor name' to response
  * Move all remaining unit tests out of tests/
* Tue Jun 16 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev62:
  * Move storage unit tests out of tests/
  * Move transport tests out of tests/
* Mon Jun 15 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev58:
  * Imported Translations from Transifex
  * Remove unused `pooling:catalog:storage` option
  * Try to use a default pool when creating a queue
  * Split `storage` into (message|management)_storage
  * Add missing doc files
  * Remove the sqlite entry point
  * Remove messages and claims from sql code
  * Move transport v1 tests out of tests/
  * Deprecate v1
  * Remove `marconi-server`
  2015.1.0
  * Release Import of Translations from Transifex
  * update .gitreview for stable/kilo
  * Updated from global requirements
* Sat Jun  6 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev41:
  * Move transport v1_1 tests out of tests/
* Fri Jun  5 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev40:
  * Move transport v2 tests out of tests/
  * Speed up message expiration tests
  * Clarify code comment in Redis backend
  * Switch from MySQL-python to PyMySQL
  * Using oslo.context
* Thu Jun  4 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev30:
  * Add cleanups to several tests
  * Imported Translations from Transifex
* Wed Jun  3 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev27:
  * s/Marconi/Zaqar/ in method docstring
  * Port to oslo_log
* Wed May 27 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev24:
  * Drop incubating theme from docs
  * Enable pooling in devstack
  * Imported Translations from Transifex
  * Fix duplicated test cases of notifier
* Tue May 26 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev17:
  * Delete unused README links
* Fri May 15 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev16:
  * Replace ci.o.o links with docs.o.o/infra
  * Imported Translations from Transifex
* Tue May 12 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev13:
  * Drop use of 'oslo' namespace package
* Sat May  9 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev11:
  * Set unreliable True
  * Fix gate_hook and post_test_hook perms
* Thu May  7 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev9:
  * Add gate hooks to enhance Zaqar's job
  * Add function dispatchers
* Tue May  5 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.0.dev7:
  * Update dataplane section name
  * Remove support for sqlalchemy in devstack
  * Rename service to zaqar
* Fri May  1 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.dev6:
  * Install packages from plugin.sh
* Mon Apr 27 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.dev5:
  * Move devstack's Zaqar code into the codebase
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.dev4:
  * makes uri unique to avoid duplicated pools
* Wed Apr 15 2015 cloud-devel@suse.de
- Update to version zaqar-2015.2.dev2:
  2015.1.0rc1
  * Open Liberty development
* Tue Apr 14 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev30:
  * Adds a test for queues validations
* Mon Apr 13 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev28:
  * Fix instructions in README.rst file
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev26:
  * Updated from global requirements
* Fri Apr  3 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev25:
  * Remove QueueController from data to control plane
  * Imported Translations from Transifex
* Thu Apr  2 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev22:
  * Add websockets to our test suite
  * Imported Translations from Transifex
  * Implement webhook notifier driver
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev17:
  * Adds message processing to WebSockets driver
  * Implement redis driver for notifications
  * Add REST API for notification/subscriptions
  * Updates the readme.rst file to add dependencies steps
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev9:
  * Allow for internal pipelines to be defined
  * Imported Translations from Transifex
* Mon Mar 30 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev6:
  * Remove sqlalchemy from our data plane
* Sat Mar 28 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev4:
  * Correcting Instruction For Mongodb URI in README.rst
* Wed Mar 25 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev2:
  2015.1.0b3
  * Updated from global requirements
  * Update json schema for API v1_1
  * Fix common misspellings
  * Use generate_uuid() from oslo.utils
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev23:
  * Adds a status code field to the Response
  * This change adds missing help strings for claims
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev19:
  * Make the Pipeline inmutable
* Sat Mar 14 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev18:
  * Adds a representation for the Request and Response objects
  * Syntax enhancements
* Fri Mar 13 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev14:
  * Clean up inconsistent if statement syntax in transport auth
  * Adds websockets driver to Zaqar server
  * Updated from global requirements
* Sat Feb 21 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev9:
  * Updated from global requirements
  * Imported Translations from Transifex
* Thu Feb 19 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev7:
  * API handler and API v1.1 Queue endpoints
* Tue Feb 17 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev5:
  * Use pool's capabilities for flavors in v2
  * Split MongoDB's default implementation from FIFO's
* Mon Feb 16 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev3:
  * Forbid adding stores with mismatching capabilities
* Sat Feb 14 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev2:
  * Replace API v1 with v1.1 in README
* Fri Feb 13 2015 dmueller@suse.com
- update logrotate.conf
* Thu Feb 12 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev1:
  * Expose healt in homedoc
  2015.1.0b2
* Wed Feb  4 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev24:
  * Imported Translations from Transifex
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev23:
  * Refactor Api classes to enhance consistency
* Thu Jan 29 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev21:
  * Updated from global requirements
* Wed Jan 28 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev20:
  * Move oslo libraries out of the oslo namespace
* Wed Jan 21 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev19:
  * Check marker before accessing it
* Tue Jan 20 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev18:
  * Implement mongodb driver for notifications
* Thu Jan 15 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev16:
  * Updated from global requirements
  * Fork v1_1 of the API into v2
  * Invalid grave accents at the end of the mongodb installation URLs
* Tue Jan 13 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev12:
  * Fix the last assertion in test_impl_mongodb.test_message_counter
* Thu Jan  8 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev11:
  * Version discovery for root URI
* Mon Jan  5 2015 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev10:
  * Imported Translations from Transifex
  * Use the oslo.serialization instead of openstack/common/jsonutils
* Thu Dec 25 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev7:
  * Removed includes for zaqar.config.sample from doc
* Wed Dec 24 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev5:
  * Use keystoneclient auth and register required options
  * Clean up the 'queues' package for tests
  * Slighty refactoring for the cross api spec
* Fri Dec 19 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.0b1:
  2015.1.0b1
  * Temporally remove Sphinx from test-requirements-py3
  * Updated from global requirements
  * Clean up pooling meta-controllers
  * Expose pools and flavors in homedoc
* Tue Dec 16 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev92.g561f000:
  * Fix the duplicate lines in autoindex doc
* Sat Dec 13 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev91.g7e94de2:
  * Wrap abstract method with base methods
  * Add capabilities property to the DataDriver
  * Split Control and Data planes of Storage layer
* Fri Dec 12 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev86.g57f0a87:
  * Remove the outdated openstack common modules
* Thu Dec 11 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev84.g3bc7f52:
  * Imported Translations from Transifex
  * Removes ZMQ directory
* Wed Dec 10 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev81.gc4c7b75:
  * Refactor code structure for notification
* Tue Dec  9 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev79.g508979f:
  * Updated from global requirements
  * Workflow documentation is now in infra-manual
* Sat Dec  6 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev76.g1370e9b:
  * Don't register pool endpoints when pooling=False
* Wed Nov 26 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev75.gcb45cc6:
  * Replace sqlite with sqlalchemy
  * Document mongodb's driver deployments
  * Rename rally-scenarios/ to rally-jobs/
  * Test message delete when claim expires
* Mon Nov 24 2014 dmueller@suse.com
- Update to version zaqar-2015.1.dev69.gfa17a25:
  * Add rally job related files
  * Add instructions on generating sample config
  * Make the refrence to storage.errors to be consistent
  * Used a pooled config for health
  * Correctly stop functional servers
  * Update oslo-config-generation code
  * Claim post requires a body
  * pooling conf is using a wrong deprecated conf
  * Remove config sample and generate it using code
  * Let the test client serialize request's body
  * Always include the project id in the logs
  * remove the old name conf file
  * Capture the stdout and stderr based on environment
  * Why do we increment the counter after the insert?
* Fri Nov 14 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev45.g50cdfc9:
  * Imported Translations from Transifex
  * Updated from global requirements
* Thu Oct 30 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev42.gec30ebf:
  * Updated from global requirements
* Wed Oct 29 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev41.g8a106bd:
  * Imported Translations from Transifex
  * Fix the doc typo
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev38.g67bb04c:
  * Put a cap on our cyclomatic complexity
  * Fix the exception raised when running test by nose
  * Sync the zaqar.conf.sample file
* Thu Oct 16 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev32.g814c945:
  * Updated from global requirements
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev31.gac00d2b:
  * Fix ttl and grace story for claims updates
* Tue Oct 14 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev29.g6cdaa0a:
  * Fix no links property in flavor list response
* Mon Oct 13 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev27.g117b01b:
  * Fix no links property in pool list response
  * Reduce duration of some long-running tests
* Sat Oct 11 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev23.g747d84b:
  * Imported Translations from Transifex
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev22.gce66ec9:
  * Queue's empty list should return 200 and an object
  * Remove all traces of nose
  * Fix the param name typo
  * Updated from global requirements
  * Fix the msg encode/decode error
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev13.gafa547e:
  * Add support for redis-sentinel
  * Move marker field to the first position (index)
* Wed Oct  8 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev10.gb386d6d:
  * Fix the typo in the description of the write concern error
  * Move the module reference to the top
* Sat Oct  4 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev7.g41afbed:
  * Imported Translations from Transifex
* Fri Oct  3 2014 cloud-devel@suse.de
- Update to version zaqar-2015.1.dev6.g3838217:
  * Add first reliability enforcement
  * Imported Translations from Transifex
  * Open Kilo development
  2014.2.rc1
  * Fix coverage testing
* Thu Oct  2 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev84.gb5025dc:
  * Add a pool_group to pools in v1.1
  * Improve efficiency of the redis driver when posting messages
  * Move Redis driver's claim transaction to Lua
* Thu Oct  2 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev78.g346ccd1:
  * Don't skip pools' functional tests
  * Accept existing conf in dynamic_conf
* Wed Oct  1 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev74.g7099bb0:
  * V1.1: Add id property to messages in claims
  * Don't register options in __init__
* Mon Sep 29 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev70.g75c89a0:
  * Fix typo in README
  * Use OpenStack Incubated branding for docs
  * Imported Translations from Transifex
  * Fix regression: No handlers could be found for logger when start
  * Fixes docstring typos
  * Enable ZAQAR_TEST_SLOW for py27
  * Add genconfig to tox.ini
* Mon Sep 29 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev56.g81526ce:
  * Updated from global requirements
* Sat Sep 27 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev54.g8d64415:
  * Added checks enforcements rule to the developers manual
* Fri Sep 26 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev52.g6253626:
  * Replace misleading max_message_size option name
* Sun Sep 21 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev51.g0f75fdc:
  * Catch Exception instead of RuntimeError for driver
  * Imported Translations from Transifex
  * Add the redis opts to the generate sample shell script
  * Removes claim_id param in v1.0
  * Add _ prefix to local variables
* Thu Sep 18 2014 dmueller@suse.com
- Update to version zaqar-2014.2.dev42.gf218b60:
  * Stop using intersphinx
  * Not permitted to delete pools which are used by flavor
  * Workaround pypy bug on trusty when running tests
  * Remove test_correct_has from our test suite
  * Don't import client from the version package
  * Updated from global requirements
  * Remove extraneous created_iso property
  * Fix messages getting reclaimed in the Redis driver
  * Imported Translations from Transifex
  * Update Zaqar backend requirements
  * In the Redis driver, only read the msg body when needed
  * Fix: Redis driver does not fall back to default port
  * Add missing flavors_controller method to Redis driver
  * Adds the API reference to the devs guide
  * Remove recursive imports
  * Add a dox.yml config file
  * Add ZAQAR_TEST_EVERYTHING to enable all tests
  * V1.1: Add claim_id to message url
  * Fix pep8 error in bench tool
  * Use oslo.utils.encodeutils instead of strutils
  * Updated from global requirements
  2014.2.b3
  * Don't pass pipe when filtering messages in the Redis driver
  * In benchmark observer worker, include claimed messages when listing
  * Work toward Python 3.4 support and testing
  * Switch Redis driver modules over to oslo.utils.timeutils
  * Calculate stats dynamically instead of using side counters
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev108.g7f1baf7:
  * Zaqar configuration reference docs
  * Don't return content_location anymore
  * Make X-Project-ID a required header
  * Imported Translations from Transifex
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev100.gb98d93e:
  * Adds partial field deprecation note in the users guide
* Tue Sep  2 2014 tbechtold@suse.com
- Update to version zaqar-2014.2.dev98.g89aa8d0:
  * Ensure `pool` exists before creating a flavor
  * Fix the flavor tests failing under py33
  * Raise proper HTTP error when flavor doesn't exist
  * Imported Translations from Transifex
  * Adds more resources section to to developers guide
  * Enhance docstrings for the config reference
  * Implements queue, message and claim controllers for Redis
  * Add observer role to benchmark tool
- Rename zaqar-bench-pc to zaqar-bench
* Sat Aug 30 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev84.g6472ed4:
  * Do not fail silently when given a bogus claim ID
* Fri Aug 29 2014 cloud-devel@suse.de
- Update to version zaqar-2014.2.dev83.gab1d471:
  * Make the catalog flavor-aware
* Sun Aug  3 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev17.gcb1d526:
  * Fix py3k incompatibility with itertools.ifilter
  * Mark sqlalchemy's data driver as deprecated
* Sat Aug  2 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev13.g90cd53a:
  * Fixes several failing mongo driver tests
* Fri Aug  1 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev11.g1f39b79:
  * Correct the test instructions in README
* Thu Jul 31 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev9.gb99595b:
  * Updated from global requirements
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev8.gfd2616d:
  * Filter out expired messages
* Tue Jul 29 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev7.gafd6d05:
  * Updated from global requirements
  * Deprecate partial field in v1.0, remove in v1.1
* Sat Jul 26 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev3.g526170d:
  * Minor cleanup of utils unit test
* Fri Jul 25 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev1.g11cdb89:
  * Imported Translations from Transifex
  2014.2.b2
* Thu Jul 24 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev75.gb3f1b48:
  * API v1.1 - Encapsulate message post bodies in a JSON object
  * Rename remaining 'shard' to 'pool'
  * Remove check queue exists endpoint
* Wed Jul 23 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev69.g79f0d22:
  * Updated from global requirements
  * feat(v1.1): Default TTL and grace values
* Fri Jul 18 2014 vuntz@suse.com
- Update to version marconi-2014.2.dev66.g53f3fa6:
  * Imported Translations from Transifex
  * feat(benchmarking) : Producer-Consumer scenario
  * Adding dependencies for redis support in marconi
  * Implement POP in v1.1 API
  * Drop pylint due to the huge amount of false positives
- Put the new marconi-bench-pc tool in test subpackage, as it
  probably fits best there.
* Sun Jul 13 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev60.g3c80522:
  * Run storage unit tests in pooled context
  * Make storage/pooling reflect storage/base
* Sat Jul 12 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev56.g5edf296:
  * Updated from global requirements
  * Primary key for pool in catalogue table is unreasonable
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev53.g51a98ce:
  * Changing default type for pooling Catalog storage driver
  * Start scratching Queue Flavors api
* Thu Jul 10 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev49.g994adf9:
  * Switch over oslo.i18n
* Wed Jul  9 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev47.g8c6b80e:
  * Fix typos
  * Clean up queues created for certain tests
  * Use the class queue_name and project for tests
  * limit=0 in sqlalchemy means 0 instead of unlimited
  * Wrong param order when using errors.QueueNotMapped
* Tue Jul  8 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev40.g0975fed:
  * Fix broken wiki link
* Tue Jul  1 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev39.gc5106bc:
  * Add None checking for the Mongodb uri
* Thu Jun 26 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev38.gc0e7c6a:
  * Remove alphabetical sorting assumption in tests
* Wed Jun 25 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev36.g4dfb4e9:
  * V1.1 Functional Tests
  * Updated from global requirements
  * Rename shard to pool
  * Fix two caching-related comments in the code
  * Correct the rtype in the function docstrings
  * Fix Python 3 leftovers
  * Sync with oslo-incubator
  * Expose pymongo's SSL cert options
* Fri Jun 20 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev21.gf11286a:
  * Removed buggy httpretty to unblock the gate
* Wed Jun 18 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev20.g22584f4:
  * Updated from global requirements
  * Update hacking version and fix new violations
  * Rename shards to pool
  * Updated from global requirements
  * Make storage.utils.keyify py3k compatible
* Tue Jun 17 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev11.gc4674d7:
  * Implement Lazy Create Queue in v1.1 API
  * Sync from oslo-incubator
  * Fix tests to be Python 3 compatible
  * remove default=None for config options
  * Refactor auxiliary methods for MongoDB unit tests
  * Re-enable tests affected by #1321840
* Thu Jun 12 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.b1:
  2014.2.b1
  * Decoupled Unit Tests
  * fix: Checking whether queue exists adds latency
* Tue Jun 10 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev47.g6f039e3:
  * Small fixes in storage drivers for Python 3
* Mon Jun  9 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev45.gec6c6ea:
  * Prepare marconi for localization
* Wed Jun  4 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev44.g366d9b5:
  * Removed now unnecesary workaround for PyPy
  * Fix handling of request/response body for Python 3
  * Fix sqlalchemy storage driver for Python 3
* Tue Jun  3 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev39.gb5cdeb0:
  * V1 Tests JsonSchema
* Fri May 30 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev37.g99afac4:
  * Updated from global requirements
* Thu May 29 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev36.g7c1de0e:
  * Synced jsonutils from oslo-incubator
* Mon May 26 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev35.g29daec0:
  * Add separate requirements file for Python 3
* Sun May 25 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev33.g8530fd7:
  * Fixed a few typos in the codebase
* Thu May 22 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev32.g2b5f301:
  * Revert "Disable Metadata write operations on v1.1"
  * Updated from global requirements
* Sat May 10 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev29.g1f7dcd5:
  * Updated from global requirements
  * Fixing some spelling, grammar, etc in docs
* Wed May  7 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev26.g74eb5eb:
  * Fixed incorrect reST syntax
* Wed Apr 30 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev25.g44f2850:
  * Updated from global requirements
* Tue Apr 29 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev24.g399fa74:
  * Removes host header from functional tests
  * Synced jsonutils from oslo-incubator
* Thu Apr 24 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev21.g39d4a09:
  * fix(metadata): Fix inconsistent error response under v1.1
  * Use jsonschema for testing queue
* Wed Apr 23 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev19.gb70ab33:
  * fix(metadata
* Tue Apr 22 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev18.g3542331:
  * Updated from global requirements
* Mon Apr 21 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev17.gae4f836:
  * Adds command line option "daemon" to Marconi
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev16.gcc19975:
  * Disable Metadata write operations on v1.1
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev14.g0368aed:
  * Instantiate app only when needed
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev12.g91b826e:
  * Remove MySQL-python from the dependency list
  * fix(sharding): deregister queue before delete
  2014.1.rc1
* Fri Apr 11 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev75.gec302a5:
  * Use config options to determine message count
  * Dedup HACKING.rst and remove any pep8 or OpenStack hacking rules
* Thu Apr 10 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev71.g120a7cf:
  * Updated from global requirements
* Sun Apr  6 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev70.g635e9fb:
  * Add specific doc build option and gate on warnings
* Sat Apr  5 2014 cloud-devel@suse.de
- Update to version marconi-2014.2.dev68.g5b82031:
  * Update comment for version to say "Juno" instead of "Icehouse"
  * Open Juno development
* Thu Apr  3 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev66.g08841d1:
  * Don't fork marconi-server unless USE_SCREEN=False
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev65.g43883fc:
  * Improve cleanup of test_insert_queue_header_asterisk
* Sun Mar 30 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev63.ga27a279:
  * Add a help text for auth_strategy
* Sat Mar 29 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev61.g29852ae:
  * keystone middleware version change due to a bug
* Fri Mar 28 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev60.g06667a3:
  * keystoneclient now supports Py3K
  * Add keystone_authtoken to our config generator
  * fix() : introduce division import
  * Fix message.first return value for mongodb
* Thu Mar 27 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev54.gae7f498:
  * Switch to oslosphinx
  * Add default mongod URI to README
* Wed Mar 26 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev51.g4efe0af:
  * fix(
  * Fix functional config file instructions
* Mon Mar 24 2014 dmueller@suse.com
- fix requires
* Sun Mar 23 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev48.g9e38b12:
  * Updated from global requirements
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev47.gad45cce:
  * Add more unit tests for message controller
  * Include full license text
  * Update license headers on select source files
* Wed Mar 19 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev43.g5ce7f69:
  * Marconi Operations Document
  * adds docs directory with dev guide
  * fix(gate): one for pypy, one for docs
* Mon Mar 17 2014 speilicke@suse.com
- Update to version marconi-2014.1.b2.dev39.ge6431b5:
  * Rename logging.conf-sample to logging.conf.sample
  * Fix config file name in README instructions
* Fri Mar 14 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev35.g42a39e1:
  * Improve README file
  * Enable the basic dev doc for Marconi
  * Keep python 3.X compatibility for xrange
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev29.g122aeac:
  * Allow marconi-server to properly daemonize
* Wed Mar 12 2014 speilicke@suse.com
- Update to version marconi-2014.1.b2.dev28.ga4ed60f:
  * Use oslo's config generator to generate sample
  * Prepare Marconi to support oslo's config.generator
  * Add an options module to sqlalchemy
  * Updated from global requirements
  * Use a colon instead of a . in setup.cfg
  * Sync from oslo-incubator
  * Add MySQL-python as a dependency
  * Add missing logging trace queues collection
  * fix(cli): Print statement in global error handler
- Fix marconi.conf.sample installation
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev15.gce20e91:
  * Enable shards test for sqlalchemy
  * Remove unused method from timeutils
  * Reuse the transaction before getting messages
  * Set time_zone to UTC on MySQL
  * MySQL requires VARCHARs to have a length
  * Slighty refactored url_prefix usage in WSGI tests
  * Update marconi.conf-sample to deprecate sqlite
  2014.1.b3
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev73.gbf055a4:
  * Replace `Sqlite` with `Sqlalchemy` in test names
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev72.gedae7f3:
  * Removed debug level messages translations
  * fix(MongoDB): Driver does not retry on AutoReconnect errors
  * Fix assertion for Testutils to check on sqlite://:memory:
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev66.g266ca53:
  * Deprecate sqlite in favor of sqlalchemy
  * fix(mongodb): Limit kwarg must be an int
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev63.gbbcd593:
  * Don't raise `DoesNotExist` on claims deletion
  * Register sqlalchemy endpoints
  * Fix message's get and deletion
  * Enable pragma foreign key for sqlite
  * test(wsgi): Refactor tests in preparation for API v1.1
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev57.gd8341ad:
  * Remove termios support (and associated issues)
  * test(wsgi): Enable test_default_limits and fix UUID bug
* Thu Feb 27 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev55.g8ba3ff6:
  * Updated from global requirements
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev54.gca2e1d2:
  * test(wsgi
* Mon Feb 24 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev53.g6f35b34:
  * Add an sqlalchemy storage to Marconi
  * Updated from global requirements
* Sat Feb 22 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev51.g8a4938e:
  * feat(sql/catalogue): add catalogue controller
  * feat(sqlalchemy): add shards controller
  * Replace unicode() by six.text_type for python3 compatability
  * Replace basestring by six for python3 compatability
  * feat(v1.1): Implement /ping endpoint for v1.1
  * fix(wsgi): Cleanup limit config options
* Thu Feb 20 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev42.gffb625a:
  * feat(v1.1): Plumb v1.1 API in the WSGI transport
  * Sync common modules from olso and remove py3kcompat
  * fix(wsgi
* Wed Feb 19 2014 dmueller@suse.com
- switch over to non-openstack prefixed user
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev38.g724620d:
  * doc(README): Have the user pass '-v' when starting marconi-server
  * Fix misspellings in marconi
* Tue Feb 18 2014 cloud-devel@suse.de
- Update to version marconi-2014.1.b2.dev34.g08c53ff:
  * Fix two small typos in marconi/queues/storage/sharding.py
  * feat(sql/driver): expose ControlDriver, more config
  * Apply six for metaclass
  * Use six.moves.urllib.parse instead of urlparse
  * Improve help strings
  * fix(wsgi): Cleanup limit config options
* Wed Feb 12 2014 speilicke@suse.com
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Thu Feb  6 2014 dmueller@suse.com
- fix typo in logrotate
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev16.gd99e975:
  + DRY applied to class names
* Fri Jan 31 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev14.g9e3eb13:
  + test(functional): Don't use a dead test server
  + chore: Fix pylint errors
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev12.g7384b1e:
  + fix(testtools): 0.9.35 is not compatible with subunit 0.0.17
* Tue Jan 28 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev11.g2757da0:
  + Skip message_get_many schema test until we can repro reliably
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev10.g8faf500:
  + Remove dev1 from version, since it is added automagically by pbr
  + fix: ConnectionError no longer takes positional arguments
  + fix(mongodb): Ensure batch message posts are atomic (all or nothing)
  + Drop msgpack dependency
  + Sync oslo-cache from oslo-incubator
  + Don't use `override_time` but mock instead
  + Add a _config_options function to Marconi
  + fix: Move decorator out of class definition since it is static
  + chore: Add pylint envs
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev573.gb14c7e0:
  + Added a request and response file to common
  + Use testr instead of nosetest
  + Enforce size verification on content-length
* Fri Jan 17 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev567.g1765a8c:
  + test: Use srmock header_dict in preparation for Falcon 0.1.8
* Wed Jan 15 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev565.gd4e3dca:
  + Remove __MARCONI_SETUP__
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev563.gc317e64:
  + chore: Sync local (marconi) requirements with global reqs
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev561.g13d9fa2:
  + Verify response jsonschema for List Messages by ID
  + Map HTTP request codes in jsonschema
* Tue Jan  7 2014 speilicke@suse.com
- Update to version 2014.1.b2.dev1.dev557.ga8e2805:
  + Implement tables and unit tests for sqlalchemy storage backend
  + Implement DataDriver for sqlalchemy storage backend
  + Change shards & catalogue db into single property
* Tue Jan  7 2014 dmueller@suse.com
- remove falcon-unlimited.diff: merged upstream
* Thu Jan  2 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev553.g4e36b21:
  + DRY queues storage error message format
* Tue Dec 24 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.b2.dev1.dev551.g495eb46:
  + chore: Bump version to icehouse-2 dev
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev549.g35bc36f:
  + Added logging to HTTP errors
* Sat Dec 14 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev548.g9c5bc99:
  + Return relative URIs for href-template of homedoc
* Tue Dec 10 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev547.g9c87eb2:
  + Make sqlite connection lazy
  + chore: Pass cache into drivers
  + feat(sharding): Cache shard mappings
  + fix(mongo): Delete claimed message fails
  + fix: mongodb tests consume storage like crazy
  + fix: shard test failing
  + cleanup: remove proxy cruft
  + opt: add hints to make delete/claim checks faster
  + Remove gettext magic and import _ explicitly
  + Disable keystone client if running under Py3K
  + Don't use tuple parameters
  + Use relative import for base in tests
  + Remove the __MARCONI_SETUP_ global from init
  + fix: Reduce logging severity of certain errors
  + Make consumer_for a context manager
  + chore: Remove remaining proxy cruft
* Wed Dec  4 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev520.gd30edc4:
  + Fixes wrong hrefs when getting set of messages
  + fix: cache contract for memcached backend
* Tue Dec  3 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev517.gdc689e6:
  + feat(shard): queue listing from multiple sources
  + Added empty packages and a test for the API v1
  + feat(validation): verify project id length
  + feat(health): make health API storage-aware
* Thu Nov 28 2013 cloud-devel@suse.de
- Rebased patches:
  + patches/falcon-unlimited.diff (only offset)
  + falcon-unlimited.diff (manually)
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev509.g11660c2:
  + refactor: drop simplejson requirement
* Mon Nov 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev507.gb20519c:
  + Start 2014.1 development
  + Support building wheels (PEP-427)
  + Sync with global requirements
  + feat: connect sharding manager to control drivers
  + Isolate tests a bit more
  + Revert "Support building wheels (PEP-427)"
  + Cleans up marconi-queues and marconi-proxy config files
  + Remove proxy code
* Sat Nov 16 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.dev494.g2f44ed5:
  + Update openstack/common/lockutils
* Fri Nov  1 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.dev493.g8338bdc:
  + feat: integrate shard storage with transport
  + Add Tests for non-existing resources
* Thu Oct 31 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.dev490.g5624bf1:
  + feat: add catalogue storage driver for queues
  + Renamed "exceptions" module to "errors"
* Wed Oct 30 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.dev488.gea79e2b:
  + feat: shards mongodb driver + tests
  + feat(logging): format msg when log level met
* Tue Oct 29 2013 dmueller@suse.com
- add falcon-unlimited.diff
* Tue Oct 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.dev484.g43c507b:
  + feat: shards storage controller interface
  + Update the Marconi readme with more detailed installation instructions
* Fri Oct 25 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a481.ga24ce88:
  + feat: split queues API into public/admin
  + feat: add shard management resource
* Thu Oct 24 2013 dmueller@suse.com
- fix requires
* Wed Oct 23 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a477.ge85fe34:
  + Don't enable_echo when we don't have a tty
* Mon Sep 30 2013 dmueller@suse.com
- switch to crudini
* Wed Sep 18 2013 dmueller@suse.com
- fix requires
* Thu Sep  5 2013 speilicke@suse.com
- Init script, logrotate and update. Several minor fixes
* Thu Aug  1 2013 speilicke@suse.com
- Only require discover on SLE
* Wed Jul 17 2013 speilicke@suse.com
- Initial version
